# Security Policy

## Supported Versions

| Version    | Supported          |
| ---------- | ------------------ |
| >= 0.5   | :white_check_mark: |

## Reporting a Vulnerability

Please report any security vulnerabilities to rio.labs@outlook.com